summaryrefslogtreecommitdiff
path: root/Modules/CMakeJavaInformation.cmake
diff options
context:
space:
mode:
authorDavid Cole <david.cole@kitware.com>2008-03-13 15:03:20 -0400
committerDavid Cole <david.cole@kitware.com>2008-03-13 15:03:20 -0400
commit908a2b462d762e24eab8fa1569eac05ce8a16438 (patch)
tree0deefb4138cf16e0f6d3bed9c03c46f6a489fad8 /Modules/CMakeJavaInformation.cmake
parenta313a098d0e444c67702a0e4f0c8b0ed145e3269 (diff)
downloadcmake-908a2b462d762e24eab8fa1569eac05ce8a16438.tar.gz
COMP: Conditionalize the last change so that the fix only applies to WIN32. Leave it the way it was elsewhere, the new way does not work on the Mac continuous dashboard...
Diffstat (limited to 'Modules/CMakeJavaInformation.cmake')
-rw-r--r--Modules/CMakeJavaInformation.cmake14
1 files changed, 10 insertions, 4 deletions
diff --git a/Modules/CMakeJavaInformation.cmake b/Modules/CMakeJavaInformation.cmake
index 76b09e6bd0..cc7cf84c77 100644
--- a/Modules/CMakeJavaInformation.cmake
+++ b/Modules/CMakeJavaInformation.cmake
@@ -14,16 +14,22 @@ ENDIF(CMAKE_USER_MAKE_RULES_OVERRIDE_CXX)
# this is a place holder if java needed flags for javac they would go here.
IF(NOT CMAKE_Java_CREATE_STATIC_LIBRARY)
+ IF(WIN32)
+ SET(class_files_mask "*.class")
+ ELSE(WIN32)
+ SET(class_files_mask ".")
+ ENDIF(WIN32)
+
SET(CMAKE_Java_CREATE_STATIC_LIBRARY
- "<CMAKE_Java_ARCHIVE> -cf <TARGET> -C <OBJECT_DIR> *.class")
- # "*.class" should really be "<OBJECTS>" but compling a java file can create
- # more than one .class file, so for now get all of them
+ "<CMAKE_Java_ARCHIVE> -cf <TARGET> -C <OBJECT_DIR> ${class_files_mask}")
+ # "${class_files_mask}" should really be "<OBJECTS>" but compling a *.java
+ # file can create more than one *.class file...
ENDIF(NOT CMAKE_Java_CREATE_STATIC_LIBRARY)
# compile a Java file into an object file
IF(NOT CMAKE_Java_COMPILE_OBJECT)
SET(CMAKE_Java_COMPILE_OBJECT
- "<CMAKE_Java_COMPILER> <FLAGS> <SOURCE> -d <OBJECT_DIR>")
+ "<CMAKE_Java_COMPILER> <FLAGS> <SOURCE> -d <OBJECT_DIR>")
ENDIF(NOT CMAKE_Java_COMPILE_OBJECT)
# set java include flag option and the separator for multiple include paths